tags_map = {
    'stats': {
        'label': 'Statistics',
        'order': 100
    },
    'ml': {
        'label': 'Machine Learning',
        'order': 103
    },
    'ai': {
        'label': 'Artificial Inteligence',
        'order': 102
    }
}

tags_ignored = ['some', 'tags', 'to', 'ignore']
